@@ -1,6 +1,4 @@
 from .core import SalesforceCore
 
 
-__all__ = [
-    'SalesforceCore'
-]
+__all__ = ["SalesforceCore"]
